pub trait ToHexPrefixed {
// Required method
fn to_hex_prefixed(self) -> String;
}Expand description
Encodes data into an hexadecimal encoded string with a 0x prefix.
Required Methods
Sourcefn to_hex_prefixed(self) -> String
fn to_hex_prefixed(self) -> String
Encodes data into an hexadecimal encoded string with a 0x prefix.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".